<template>
    <div class="report-container">
        <div class="report-overview" v-loading="loading" element-loading-background="rgba(1, 33, 90, 0.8)">
            <Docx
                :fileUrl="options.url"
                :fileId="options.fileId || fileId"
                v-if="!loading"
            />
        </div>
    </div>
</template>

<script>
import Docx from '@/components/docx/index.vue'
import apiList from '@/api/bigScreen/districView.js'
export default {
    name: 'docPreview',
    components: {Docx},
    props: {
        options: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            fileId: ''
        }
    },
    watch: {
        'options.url': {
            handler: function () {
                this.loading = true
                this.updateDoc()
            },
            immediate: true,
        },
        'options.fileId': {
            handler: function (newVal) {
                this.loading = true
                this.updateDoc()
            },
            immediate: true,
        },
    },
    mounted() {
        let date = JSON.parse(sessionStorage.getItem('searchDate'))
        if (this.options.type === 'satisfaction') {
            this.getSatisfaction(date)
        }
    },
    methods: {
        updateDoc() {
            setTimeout(() => {
                this.loading = false
            }, 200)
        },
        getSatisfaction(data) {
            apiList.getSatisfaction(data,res => {
                if (res) {
                    this.fileId = res.fileList[0].id
                }
            })
        }
    },
}
</script>

<style lang="scss" scoped>
.report-container{
    padding-top: 20px;
    height: calc(100% - 20px);
}
.report-overview {
    height: 100%;
    overflow: auto;
    
}
</style>